import com.digitalscores.jcdatabase.JCTable;
import com.digitalscores.jcdatabase.JCRow;

/**
* Example code for JCDatabase. This application inserts and retreives values into a table.
* The following files are required to be in the same directory:
* <p>
* DatabaseExample.java           <br>
* DatabaseExample.class          <br>
* people.def
* </code>
* <p>
* You also need jcdatabase.jar within your CLASSPATH. The Java application than then run by
* typing "javac DatabaseExample".
* <p>
* If the code is inserted within an Applet rather than an Application then then an additional
* file named ' polfile' needs to be saved in the same directory, containing the following text:
* <p>
* <code>grant {                                                                <br>
*  permission java.util.PropertyPermission "user.home", "read";                <br>
*  permission java.io.FilePermission "${user.home}/test.txt", "read,write";    <br>
*  permission java.io.FilePermission "people.def", "read,write";               <br>
*  permission java.io.FilePermission "people.dat", "read,write";
*};</code>
*
* Applets can access the local drive by typing "appletviewer -J-Djava.security.policy=polfile applet.html"
*/

class DatabaseExample {

  public static void main(String argv[]) {

    // Create reference to the physical table 'people.dat'
    JCTable people = new JCTable("PEOPLE");

    // Insert a row of data into the table
    people.insert("FIRST_NAME=Michael LAST_NAME=Jenkins YEAR_OF_BIRTH=1973 HEIGHT=5.92");

    // Create a new row of data in memory
    JCRow newRow = new JCRow(people);

    // Use this row of data to insert three more records using an alternative syntax
    newRow.setString("FIRST_NAME", "James");
    newRow.setString("LAST_NAME", "Cochran");
    newRow.setInt("YEAR_OF_BIRTH", 1973);
    people.insert(newRow);
    newRow.setString("FIRST_NAME", "Galya");
    newRow.setString("LAST_NAME", "Malashenkova");
    newRow.setInt("YEAR_OF_BIRTH", 1954);
    people.insert(newRow);
    newRow.setString("FIRST_NAME", "Julian");
    newRow.setString("LAST_NAME", "Cochran");
    newRow.setInt("YEAR_OF_BIRTH", 1974);
    people.insert(newRow);

    // Change the first name to 'Jack' for anyone named 'James'
    people.update("FIRST_NAME", "Jack", "FIRST_NAME", "=", "James");

    // Display the names of everyone born before 1974
    JCRow[] result = people.select("YEAR_OF_BIRTH", "<", 1974);
    for (int i = 0; i < result.length; i++) {
      System.out.println(result[i].getString("FIRST_NAME") + " " + result[i].getString("LAST_NAME"));
    }
  }
}
